# Python Web Robot Builder

[![Build Status](https://travis-ci.org/OpenCIAg/py-robot.svg?branch=master)](https://travis-ci.org/OpenCIAg/py-robot)
[![Pypi](https://badge.fury.io/py/ciag-robot-ami.svg)](https://badge.fury.io/py/ciag-robot)
[![Maintainability](https://api.codeclimate.com/v1/badges/4116e2ba99ce56e1397e/maintainability)](https://codeclimate.com/github/OpenCIAg/py-robot/maintainability)
[![Test Coverage](https://api.codeclimate.com/v1/badges/4116e2ba99ce56e1397e/test_coverage)](https://codeclimate.com/github/OpenCIAg/py-robot/test_coverage)

.. image:: 
    :target: 

## Instalação

```shell
pip install ciag-robot
```
